{% extends "main/layout.html" %} {% load crispy_forms_tags %} {% block title %} {{title}} {% endblock title %} {% block content %}{% include 'development/sidebar.html' %}

<section class="section-container">
  <!-- Page content-->
  <div class="content-wrapper">
    <div class="content-heading d-flex justify-content-between">
      <div>
        {{title}}<small>
          <ol class="breadcrumb mt-3">
            <li class="breadcrumb-item"><a href="{% url 'dashboard' %}">Varanda</a></li>
            <li class="breadcrumb-item active" aria-current="page">{{title}}</li>
          </ol>
        </small>
      </div>
      <div>
              {% ifequal user.groups.all.0.name 'admin' %}
              <div class="bg-danger p-2">
              <small class="text-white">Admin Nasional MAE</small>
              </div>
              {% endifequal %}
              {% ifequal user.groups.all.0.name 'xefe' %}
              <div class="bg-warning p-2">
              <small class="text-white"> Xefe Suku {{user.employeeuser.employee.village}}</small>
              </div>
              {% endifequal %}
              {% ifequal user.groups.all.0.name 'sec' %}
              <div class="bg-warning p-2">
              <small class="text-white"> Secretariado Suku {{user.employeeuser.employee.village}}</small>
              </div>
              {% endifequal %}
            </div>
    </div>
    <div class="row">
      <div class="col-xl-12">
        {% comment %} START PAGE {% endcomment %}

        <div class="row">
          <div class="col-lg-12">
            <div class="card">
              <div class="card-header d-flex justify-content-between">
                <div class="card-title">{{title}}</div>
                {% comment %}
                <div class="card-title">
                  <button onclick="self.history.back()" class="btn btn-sm btn-labeled btn-outline-info mb-2">
                    <span class="btn-label"><i class="fa fa-chevron-left"></i></span>Fila
                  </button>
                </div>
                {% endcomment %}
              </div>
              <div class="card-body">
                <form method="POST" action="" target="_blank">
                  {% csrf_token %}

                  <div class="row col-lg-12">
                    <div class="col-md-4">
                      <div class="form-group mb-3">
                        <label>Relat&oacuteriu Livru Sira</label>
                        <select required name="developmentReport" class="custom-select custom-select-sm">
                          <option selected="" value="">-----Hili Livru Atu halo Relat&oacuteriu-----</option>
                          <option value="C1">C1. Livru Dadus Projetu Suku</option>
                          <option value="C2">C2. Livru Dadus Atividade Suku</option>
                        </select>
                      </div>
                    </div>
                    <div class="col-md-4">
                      <div class="form-group mb-3">
                        <label>Tinan</label>
                        <select required name="year" class="custom-select custom-select-sm">
                          <option selected="" value="">-----Hili Tinan------</option>
                          {% for i in year %}
                          <option value="{{i.year}}">{{i.year}}</option>
                          {% endfor %}
                        </select>
                      </div>
                    </div>
                  </div>
                  <div class="col-md-8 text-center mt-4">
                    <button class="btn btn-sm btn-labeled btn-info" name="excel" type="submit" title="Excel">
                      <span class="btn-label"><i class="fas fa-save"></i></span>Exporta ba Excel
                    </button>
                    <!-- <button class="btn btn-sm btn-labeled btn-info" name="pdf" type="submit" title="PDF">
                      <span class="btn-label"><i class="fas fa-save"></i></span>Export ba PDF
                    </button> -->
                    <button class="btn btn-sm btn-labeled btn-primary" name="print" type="submit" title="PRINT"><span class="btn-label"><i class='fas fa-print'></i></span>Imprimi</button>
                  </div>
                </form>
              </div>
            </div>
          </div>
        </div>
      </div>
    </div>
  </div>
</section>
<!-- Page footer-->
{% include 'main/footer.html' %} {% endblock %} {% comment %} END PAGE {% endcomment %}
