{% ifequal load_ajax 'post' %}
	<option value="">---Select Postu---</option>
	{% for data in post %}
		<option value="{{data.id}}">{{data.name}}</option>
	{% endfor %}
{% endifequal %}

{% ifequal load_ajax 'village' %}
	<option value="">---Select Suku---</option>
	{% for data in village %}
		<option value="{{data.id}}">{{data.name}}</option>
	{% endfor %}
{% endifequal %}